@@ -13,7 +13,7 @@ from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
 
-from netbox_storage.models import Partition, PhysicalVolume
+from netbox_storage.models import Partition, PhysicalVolume, VolumeGroup
 
 
 class PhysicalVolumeForm(NetBoxModelForm):
@@ -30,6 +30,14 @@ class PhysicalVolumeForm(NetBoxModelForm):
         label="Physical Volume Name",
         help_text="Name of the physical Volume e.g. Name of the Partition /dev/sdc1",
     )
+    vg = DynamicModelChoiceField(
+        queryset=VolumeGroup.objects.all(),
+        label="VG Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:volumegroup-list")}
+        ),
+        help_text="The Volume Group for the LogicalVolume e.g. vg_docker",
+    )
     description = CharField(
         required=False,
         label="Description",
@@ -42,6 +50,7 @@ class PhysicalVolumeForm(NetBoxModelForm):
         fields = (
             "partition",
             "pv_name",
+            "vg",
             "description",
         )
 
@@ -63,6 +72,14 @@ class PhysicalVolumeFilterForm(NetBoxModelFilterSetForm):
         label="Physical Volume Name",
         help_text="Name of the physical Volume e.g. Name of the Partition /dev/sdc1",
     )
+    vg = DynamicModelChoiceField(
+        queryset=VolumeGroup.objects.all(),
+        label="VG Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:volumegroup-list")}
+        ),
+        help_text="The Volume Group for the LogicalVolume e.g. vg_docker",
+    )
     description = CharField(
         required=False,
         label="Description",
@@ -83,6 +100,14 @@ class PhysicalVolumeImportForm(NetBoxModelImportForm):
         label="Physical Volume Name",
         help_text="Name of the physical Volume e.g. Name of the Partition /dev/sdc1",
     )
+    vg = DynamicModelChoiceField(
+        queryset=VolumeGroup.objects.all(),
+        label="VG Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:volumegroup-list")}
+        ),
+        help_text="The Volume Group for the LogicalVolume e.g. vg_docker",
+    )
     description = CharField(
         required=False,
         label="Description",
@@ -98,6 +123,7 @@ class PhysicalVolumeImportForm(NetBoxModelImportForm):
         fields = (
             "partition",
             "pv_name",
+            "vg",
             "description",
         )
 
@@ -117,6 +143,14 @@ class PhysicalVolumeBulkEditForm(NetBoxModelBulkEditForm):
         label="Physical Volume Name",
         help_text="Name of the physical Volume e.g. Name of the Partition /dev/sdc1",
     )
+    vg = DynamicModelChoiceField(
+        queryset=VolumeGroup.objects.all(),
+        label="VG Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:volumegroup-list")}
+        ),
+        help_text="The Volume Group for the LogicalVolume e.g. vg_docker",
+    )
     description = CharField(
         required=False,
         label="Description",
@@ -126,7 +160,7 @@ class PhysicalVolumeBulkEditForm(NetBoxModelBulkEditForm):
     fieldsets = (
         (
             None,
-            ("partition", "pv_name", "description")
+            ("partition", "pv_name", "vg", "description")
         ),
     )
     nullable_fields = ["description"]
