@@ -150,6 +150,9 @@ class VolumeGroup(NetBoxModel):
     class Meta:
         ordering = ("vg_name", "description")
 
+    def physical_volume_count(self):
+        return PhysicalVolume.objects.filter(vg=self).count()
+
 
 class PhysicalVolume(NetBoxModel):
     partition = models.ForeignKey(
@@ -165,6 +168,11 @@ class PhysicalVolume(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='volumegroup_physicalvolume',
     )
+    drive = models.ForeignKey(
+        Drive,
+        on_delete=models.CASCADE,
+        related_name='drive_physicalvolume',
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -174,6 +182,7 @@ class PhysicalVolume(NetBoxModel):
         "partition",
         "pv_name",
         "vg",
+        "drive",
         "description",
     ]
 
@@ -244,6 +253,13 @@ class LogicalVolume(NetBoxModel):
         "description",
     ]
 
+    prerequisite_models = (
+        'netbox_storage.Filesystem',
+        'netbox_storage.VolumeGroup',
+        'netbox_storage.PhysicalVolume',
+        'netbox_storage.Drive',
+    )
+
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:logicalvolume", kwargs={"pk": self.pk})
 
